@@ -47,9 +47,9 @@ public:
                      const QSet<QByteArray> &removed) Q_DECL_OVERRIDE;
     void remove(const Akonadi::Item &item) Q_DECL_OVERRIDE;
     void remove(const Akonadi::Collection &item) Q_DECL_OVERRIDE;
-    void move(const Akonadi::Item::Id &itemId,
-              const Akonadi::Collection::Id &from,
-              const Akonadi::Collection::Id &to) Q_DECL_OVERRIDE;
+    void move(Akonadi::Item::Id itemId,
+              Akonadi::Collection::Id from,
+              Akonadi::Collection::Id to) Q_DECL_OVERRIDE;
 
     void commit() Q_DECL_OVERRIDE;
 
